<?php
/**
 * simplybiz functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, simplybiz_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * @package WordPress
 * @subpackage SimplyBiz
 */

/** Tell WordPress to run simplybiz_setup() when the 'after_setup_theme' hook is run. */
add_action( 'after_setup_theme', 'simplybiz_setup' );

if ( ! function_exists( 'simplybiz_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_custom_background() To add support for a custom background.
 * @uses add_editor_style() To style the visual editor.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 */
function simplybiz_setup() {

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary-menu' => __( 'Главная навигация', 'simplybiz' )
	) );
	
	// This theme uses custom post type for portfolio slider.
	register_post_type('portfolio', array(
		'label' => __('Портфолио'),
		'singular_label' => __('Portfolio'),
		'public' => true,
		'show_ui' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'menu_position' => 5,
		'menu_icon' => get_bloginfo('template_directory') . '/library/images/portfolio-ico.png',
		'rewrite' => true,
		'supports' => array('title', 'editor', 'thumbnail')
	));

	// This theme allows users to set a custom background
	add_custom_background();

	// Larger images will be auto-cropped to fit, smaller ones will be ignored.
	set_post_thumbnail_size( 600, 600, true );
	
	// Load all custom widgets
	require_once(TEMPLATEPATH . '/widgets.php');
	
	// Remove some defaults
	remove_action('wp_head', 'start_post_rel_link');
	remove_action('wp_head', 'index_rel_link');
	remove_action('wp_head', 'adjacent_posts_rel_link');
	remove_action('wp_head', 'next_post_rel_link');
	remove_action('wp_head', 'previous_post_rel_link');
}
endif;

/**
 * Get Theme Info - Credits: Joern Kretzschmar & Thematic
 */
 
$themeData = get_theme_data(TEMPLATEPATH . '/style.css');
$version = trim($themeData['Version']);
if(!$version)
	$version = "unknown";

/**
 * Set Theme Info in Constant
 */
 
define('THEMENAME', $themeData['Title']);
define('THEMEVERSION', $version);

/**
 * Makes some changes to the <title> tag, by filtering the output of wp_title().
 *
 * If we have a site description and we're viewing the home page or a blog posts
 * page (when using a static front page), then we will add the site description.
 *
 * If we're viewing a search result, then we're going to recreate the title entirely.
 * We're going to add page numbers to all titles as well, to the middle of a search
 * result title and the end of all other titles.
 *
 * The site title also gets added to all titles.
 *
 * @param string $title Title generated by wp_title()
 * @param string $separator The separator passed to wp_title(). simplybiz uses a
 * 	vertical bar, "|", as a separator in header.php.
 * @return string The new title, ready for the <title> tag.
 */
function simplybiz_filter_wp_title( $title, $separator ) {
	// The $paged global variable contains the page number of a listing of posts.
	// The $page global variable contains the page number of a single post that is paged.
	// We'll display whichever one applies, if we're not looking at the first page.
	global $paged, $page;

	if ( is_search() ) {
		// If we're a search, let's start over:
		$title = sprintf( __( 'Результаты поиска по запросу %s', 'simplybiz' ), '"' . get_search_query() . '"' );
		// Add a page number if we're on page 2 or more:
		if ( $paged >= 2 )
			$title .= " $separator " . sprintf( __( 'Страница %s', 'simplybiz' ), $paged );
		// Add the site name to the end:
		$title .= " $separator " . get_bloginfo( 'name', 'display' );
		// We're done. Let's send the new title back to wp_title():
		return $title;
	}

	// Otherwise, let's start by adding the site name to the end:
	$title .= get_bloginfo( 'name', 'display' );

	// If we have a site description and we're on the home/front page, add the description:
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title .= " $separator " . $site_description;

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		$title .= " $separator " . sprintf( __( 'Страница %s', 'simplybiz' ), max( $paged, $page ) );

	// Return the new title to wp_title():
	return $title;
}
add_filter( 'wp_title', 'simplybiz_filter_wp_title', 10, 2 );

/**
 * Replace wp version to theme version.
 */

function simplybiz_wp_generator()
{
	echo '<meta name="generator" content="'.THEMENAME." ".THEMEVERSION.'" />';
}
add_filter('the_generator','simplybiz_wp_generator');

/**
 * SEO: Create meta data tags.
 */
function simplybiz_create_metadata() {
	if(is_home()) {
		if ( get_option('simplybiz_meta_description') <> "" ) { echo '<meta name="description" content="'.stripslashes(get_option('simplybiz_meta_description')).'" />' . "\n"; }
		if ( get_option('simplybiz_meta_keywords') <> "" ) { echo '<meta name="keywords" content="'.stripslashes(get_option('simplybiz_meta_keywords')).'" />' . "\n"; }
		if ( get_option('simplybiz_meta_author') <> "" ) { echo '<meta name="author" content="'.stripslashes(get_option('simplybiz_meta_author')).'" />' . "\n"; }
	}
}

/**
 * SEO: Create robots.
 */
function simplybiz_create_robots() {
	global $paged;

	if((is_home() && ($paged < 2 )) || is_front_page() || is_single() || is_page() || is_attachment()) {
		$content .= "<meta name=\"robots\" content=\"index,follow\" />";
	} elseif (is_search()) {
		$content .= "<meta name=\"robots\" content=\"noindex,nofollow\" />";
	} else {	
		$content .= "<meta name=\"robots\" content=\"noindex,follow\" />";
	}
	$content .= "\n";
	if (get_option('blog_public')) {
		echo apply_filters('simplybiz_create_robots', $content);
	}
}
 
/**
 * SEO: Create canonical url.
 */
function simplybiz_canonical_url() {
	if(get_option("simplybiz_canonical") <> "") {
		if ( is_singular() ) {
			$canonical_url .= '<link rel="canonical" href="' . get_permalink() . '" />';
			$canonical_url .= "\n";        
			echo apply_filters('simplybiz_canonical_url', $canonical_url);
		}
	}
}

/**
 * Load required javascript to wp_head().
 */
function simplybiz_head_scripts() {
	$scriptdir_start .= '<script type="text/javascript" src="';
	$scriptdir_start .= get_bloginfo('template_directory');
	$scriptdir_start .= '/library/scripts/';
	$scriptdir_end = '"></script>';
	$scripts .= $scriptdir_start . 'jquery.min.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'hoverIntent.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'superfish.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'supersubs.js' . $scriptdir_end . "\n";
	$dropdown_options = $scriptdir_start . 'dropdowns.js' . $scriptdir_end . "\n";
	$scripts = $scripts . apply_filters('dropdown_options', $dropdown_options);
	$scripts .= $scriptdir_start . 'jquery.cycle.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'jquery.roundabout.min.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'jquery.roundabout-shapes.min.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'jquery.roundabout-shapes.min.js' . $scriptdir_end . "\n";
	$scripts .= '<script type="text/javascript">' . "\n";
	$scripts .= '//<![CDATA[' . "\n";
	$scripts .= 'jQuery.noConflict();' . "\n";
	$scripts .= 'jQuery(document).ready(function(){' . "\n";
	$scripts .= 'jQuery(".commentlist li:last").css("border","0");' . "\n";
	$scripts .= 'jQuery("#roundabout").roundabout({shape: "square", minScale:0.8, minOpacity:0.9});';
	$scripts .= '});' . "\n";
	$scripts .= '//]]>' . "\n";
	$scripts .= '</script>' . "\n";
	
	// Inset custom header script - via theme option
	if(get_option("simplybiz_headercode") <> "") {
		$scripts .= get_option("simplybiz_headercode") . "\n";
	}
	
	// Print filtered scripts
	print apply_filters('simplybiz_head_scripts', $scripts);
	
}
add_action('wp_head','simplybiz_head_scripts');

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function simplybiz_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'simplybiz_page_menu_args' );

/**
 * Add ID and CLASS attributes to the first <ul> occurence in wp_page_menu.
 */
function simplybiz_add_menuclass($ulclass) {
	return preg_replace('/<ul>/', '<ul class="sf-menu">', $ulclass, 1);
}
add_filter('wp_page_menu','simplybiz_add_menuclass');

/**
 * Add the proper class of menu container if wp_nav_menu is not set.
 */
function simplybiz_proper_containerclass($containerclass) {
	return preg_replace('/<div class="sf-menu">/', '<div class="menu">', $containerclass, 1);
}
add_filter('wp_page_menu','simplybiz_proper_containerclass');

/**
 * Add input fields to custom post type - portfolio.
 */
function add_portfolio(){
	add_meta_box("portfolio_details", "Ссылка для изображения Слайдера", "portfolio_image_link", "portfolio", "normal", "low");
}
function portfolio_image_link(){
		global $post;
		$custom = get_post_custom($post->ID);
		$portfolio_image_link = $custom["portfolio_image_link"][0];
?>	<div id="portfolio-options" style="padding:5px 0;">
		<p><input name="portfolio_image_link" value="<?php echo $portfolio_image_link; ?>" style="padding:8px; width:97.5%;" /></p>
		<p>Введите полный адрес ссылки для изображения на Слайдере.</p>
	</div><!--end portfolio-options-->	<?php
}
function update_portfolio_image_link(){
	global $post;
	update_post_meta($post->ID, "portfolio_image_link", $_POST["portfolio_image_link"]);
}
add_action("admin_init", "add_portfolio");
add_action('save_post', 'update_portfolio_image_link');

/**
 * Set columns for portfolio overview.
 */
function portfolio_edit_columns($portfolio_columns){
	$portfolio_columns = array(
		"cb" => "<input type=\"checkbox\" />",
		"title" => "Заголовок",
		"description" => "Описание"
	);
	return $portfolio_columns;
}
 
function portfolio_columns_display($portfolio_columns){
	switch ($portfolio_columns)
	{
		case "title":
			the_title();
			break;
		case "description":
			the_excerpt();
			break;				
	}
}
add_filter("manage_edit-portfolio_columns", "portfolio_edit_columns");
add_action("manage_posts_custom_column",  "portfolio_columns_display");

/**
 * Sets the post excerpt length to 40 characters.
 *
 * @return int
 */
function simplybiz_excerpt_length( $length ) {
	return 45;
}
add_filter( 'excerpt_length', 'simplybiz_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 *
 * @return string "Continue Reading" link
 */
function simplybiz_continue_reading_link() {
	return '<div class="continue_reading_link"><a class="css3_a" href="'. get_permalink() . '"><span>' . __( 'Читать далее &raquo;', 'simplybiz' ) . '</span></a></div>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and simplybiz_continue_reading_link().
 *
 * @return string An ellipsis
 */
function simplybiz_auto_excerpt_more( $more ) {
	return ' &hellip;' . simplybiz_continue_reading_link();
}
add_filter( 'excerpt_more', 'simplybiz_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * @return string Excerpt with a pretty "Continue Reading" link
 */
function simplybiz_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= simplybiz_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'simplybiz_custom_excerpt_more' );

/**
 * Remove inline styles printed when the gallery shortcode is used.
 *
 * @return string The gallery style filter, with the styles themselves removed.
 */
function simplybiz_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
add_filter( 'gallery_style', 'simplybiz_remove_gallery_css' );

if ( ! function_exists( 'simplybiz_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function simplybiz_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-info clearfix">
            <div class="comment-avatar clearfix">
                <?php get_avatar( $comment, 48 ); ?>
            </div><!-- .comment-author .vcard -->
    
            <div class="comment-meta commentmetadata">
            	<span class="comment-author vcard"><?php comment_author_link(); ?></span>
                <?php
                    /* translators: 1: date, 2: time, 3: permalink */
                    printf( __( '%1$s в %2$s | ', 'simplybiz' ), get_comment_date(),  get_comment_time(), get_comment_id() );
					comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) );
                ?>
            </div><!-- .comment-meta .commentmetadata -->
        </div>

		<div class="comment-body"><?php comment_text(); ?></div>
        <?php if ( $comment->comment_approved == '0' ) : ?>
			<em><?php _e( 'Ваш комментарий ожидает модерации.', 'simplybiz' ); ?></em>
			<br />
		<?php endif; ?>
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
    	<div id="comment-<?php comment_ID(); ?>">
        	<div class="comment-info clearfix">
            	<div class="comment-body">
					<p><?php _e( 'Pingback:', 'simplybiz' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Редактировать)', 'simplybiz'), ' ' ); ?></p>
				</div>
            </div>
		</div>
	<?php
			break;
	endswitch;
}
endif;

/**
 * Register widgetized areas, including two sidebars and four widget-ready columns in the footer.
 *
 * @uses register_sidebar
 */
function simplybiz_widgets_init() {
	// Area 1, located at the top of the sidebar.
	register_sidebar( array(
		'name' => __( 'Основная область для виджетов', 'simplybiz' ),
		'id' => 'primary-widget-area',
		'description' => __( 'Основная область для виджетов', 'simplybiz' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div></li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3><div class="widget-content">',
	) );
}
/** Register sidebars by running simplybiz_widgets_init() on the widgets_init hook. */
add_action( 'widgets_init', 'simplybiz_widgets_init' );

/**
 * Removes the default styles that are packaged with the Recent Comments widget.
 */
function simplybiz_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'simplybiz_remove_recent_comments_style' );

if ( ! function_exists( 'simplybiz_post_utility' ) ) :
/**
 * Prints HTML with meta information for the current author, number of comments and categories.
 */
function simplybiz_post_utility() {
}
endif;

if ( ! function_exists( 'simplybiz_post_meta' ) ) :
/**
 * Prints HTML with meta information for the current post date and edit link.
 */
function simplybiz_post_meta() {
	if(!is_attachment()) :
		printf( '<a href="%3$s" title="%4$s" rel="bookmark"><span class="entry-date">%5$s</span></a><span class="%1$s"> | Автор:</span> %2$s <span class="meta-sep"></span><span class="meta-sep"> | Рубрика:</span> %6$s <span class="meta-sep">|</span> ',
			'meta-prep meta-prep-author',
			sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
				get_author_posts_url( get_the_author_meta( 'ID' ) ),
				sprintf( esc_attr__( 'View all posts by %s', 'simplybiz' ), get_the_author() ),
				get_the_author()
			),
			get_permalink(),
			esc_attr( get_the_time() ),
			get_the_date(),
			get_the_category_list( ', ' )
		);
		comments_popup_link( __( 'Добавить комментарий', 'simplybiz' ), __( '1 комментарий', 'simplybiz' ), __( 'Комментариев: %', 'simplybiz' ) );
	else:
		printf( __('<span class="%1$s">Опубликовано</span> %2$s', 'simplybiz'),
			'meta-prep meta-prep-entry-date',
			sprintf( '<span class="entry-date"><abbr class="published" title="%1$s">%2$s</abbr></span>',
				esc_attr( get_the_time() ),
				get_the_date()
			)
		);
		if ( wp_attachment_is_image() ) {
			$metadata = wp_get_attachment_metadata();
			printf( __( '<span class="meta-sep"> | Полный размер</span> %s pixels', 'simplybiz'),
				sprintf( '<a href="%1$s" title="%2$s">%3$s &times; %4$s</a>',
					wp_get_attachment_url(),
					esc_attr( __('Ссылка на полноразмерное изображение', 'simplybiz') ),
					$metadata['width'],
					$metadata['height']
				)
			);
		}
	endif;
}
endif;

/**
 * Here lies ol custom functions
 *
 * 1.
 * Add slider gallery shortcode - use jquery cycle
 */
function add_slider_gallery($atts) {
	extract(shortcode_atts(array(
		'id' => '',
		'fx' => 'fade',
		'timeout' => '5000',
	), $atts));
	
	echo '<script type="text/javascript" language="javascript">jQuery(document).ready(function(){ jQuery("#post_js_gallery_'.$id.'").cycle({ fx:"'.$fx.'", timeout:"'.$timeout.'", containerResize: false }); });</script>';
	echo '<div id="post_slider"><div id="post_js_gallery_'.$id.'" class="post_js_gallery">';
		$args = array(
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'numberposts' => -1,
			'post_status' => 'published',
			'post_parent' => $id
		);
		$attachments = get_posts($args);
		if($attachments) {
			foreach ($attachments as $attachment) {
				$img_url = wp_get_attachment_url($attachment->ID);
				echo '<a href="'.$img_url.'"><img src="'.get_bloginfo('template_directory')."/timthumb.php?src=".$img_url.'&w=600&h=250&zc=1" /></a>';
			}
		}
	echo '</div><div style="clear:both;"></div></div>';
}
add_shortcode('post_slider_gallery','add_slider_gallery');

/**
 * 2.
 * Display all recent comments.
 */
function simplybiz_recent_comments($no_comments = 5, $comment_len = 35) {
    global $wpdb;
	$request = "SELECT * FROM $wpdb->comments";
	$request .= " JOIN $wpdb->posts ON ID = comment_post_ID";
	$request .= " WHERE comment_approved = '1' AND post_status = 'publish' AND post_password =''";
	$request .= " ORDER BY comment_date DESC LIMIT $no_comments";
	$comments = $wpdb->get_results($request);
	if ($comments) {
		foreach ($comments as $comment) {
			ob_start();
			?>
				<li>
					<a href="<?php echo get_permalink( $comment->comment_post_ID ) . '#comment-' . $comment->comment_ID; ?>"><?php echo simplybiz_get_author_in_comment($comment); ?>:
					<span><?php echo strip_tags(substr(apply_filters('get_comment_text', $comment->comment_content), 0, $comment_len)); ?></span></a>
				</li>
			<?php
			ob_end_flush();
		}
	} else {
		echo '<li>'.__('Нет комментариев', 'simplybiz').'</li>';
	}
}
function simplybiz_get_author_in_comment($comment) {
	$author = "";
	if ( empty($comment->comment_author) )
		$author = __('Аноним', 'simplybiz');
	else
		$author = $comment->comment_author;
	return $author;
}

/**
 * Handle IE8 compatibility.
 */
if (!is_admin())
	header('X-UA-Compatible: IE=EmulateIE7');
	
/**
 * Load theme options.
 */
$themename = "SimplyBiz";
$pre = "simplybiz";
$settings_navigation = array('general', 'seo', 'layout', 'integration', 'support');
	
$options = array();
	
$functions_path = TEMPLATEPATH . '/library/admin/';
	
define( OPTION_FILES, 'base.php' );
	
function startit() {
	global $themename, $options, $pre, $functions_path;
			
	if (function_exists('add_menu_page')) {
		$basename = basename( OPTION_FILES );
		add_theme_page( $themename." Настройки", "$themename Настройки", 'edit_themes', 'base.php', 'build_options');
	}
}
	
function build_options() {
	global $themename, $pre, $functions_path, $options, $settings_navigation;
	$page = $_GET["page"];
	include( $functions_path . '/options/' . $page );
	if ( isset($_GET['page']) && $_GET['page'] == "base.php" ) {
		if ( isset($_REQUEST['action']) ) {
			if ( 'save' == $_REQUEST['action'] ) {
				foreach ($options as $value) {
					if( isset( $value['id'] ) ) { 
						if( isset( $_REQUEST[ $value['id'] ] ) ) {
							if ($value['type'] == 'textarea' || $value['type'] == 'text') update_option( $value['id'], stripslashes($_REQUEST[$value['id']]) );
							elseif ($value['type'] == 'select' || $value['type'] == 'select-switch') update_option( $value['id'], htmlspecialchars($_POST[$value['id']]) );
							else update_option( $value['id'], $_POST[$value['id']] );
						}
					}
				}
				header("Location: themes.php?page=base.php&saved=true");
				die;	
			} else if( 'reset' == $_REQUEST['action'] ) {
				foreach ($options as $value) {
					if (isset($value['id'])) {
						delete_option( $value['id'] );
						if (isset($value['std'])) $$value['id'] = $value['std'];
					}
				}
				header("Location:themes.php?page=base.php&reset=true");
				die;
			}
		}
	}
	if(isset($_GET['reset']) && $_GET['reset'] == true) echo '<div id="action_info">' .$themename. ' настройки были сброшены по умолчанию.</div>';
	include( $functions_path . '/build.php' );
}
	
function build_admin_head() {
	global $functions_path;
	
	if ('themes.php' == basename($_SERVER['SCRIPT_FILENAME'])) {
		echo '<link rel="stylesheet" type="text/css" href="'.get_bloginfo('template_directory').'/library/admin/build.css" media="screen" />';
		?>
        <script type="text/javascript" src="<?php bloginfo("template_directory"); ?>/library/admin/js/epanel.js"></script>
		<script type="text/javascript" language="javascript">
			jQuery(document).ready(function(){
				//= Tipsy
				jQuery('select, input[type="text"], textarea').tipsy({gravity: 'n'});
				
				//facebox
				jQuery('a[rel*=facebox]').facebox({
					loadingImage : '<?php bloginfo("template_directory"); ?>/library/admin/images/loading.gif',
					closeImage : '<?php bloginfo("template_directory"); ?>/library/admin/images/closebox.png'
				});
				//= Navigation Tabs
				var navContainer = jQuery("#epanel #navigation").find("a");
				var optContainer = jQuery("#epanel #container").find(".primary-container");
				
				optContainer.hide().filter(':first').show();
				jQuery("#navigation a").click(function(){
					optContainer.hide();
					optContainer.filter(this.hash).css("margin-top","50px");
					optContainer.filter(this.hash).animate({ 'margin-top': '0px', opacity: 'show' }, "normal");
					navContainer.parent().removeClass("nav-selected");
					jQuery(this).parent().addClass("nav-selected");
					jQuery(this).parent()
					return false;
				}).filter(':first').click();
				
				jQuery('#defaults_button').click(function(e){
					var reset_settings = confirm("Are your sure to reset the settings?");
					if(!reset_settings){return false;}
					jQuery('#action').val("reset");
					
					var options_fromform = jQuery('#buildform').serialize();
					e.preventDefault();
					jQuery.facebox(function(){
						jQuery.ajax({
							type: "POST",
							url: "themes.php?page=base.php",
							data: options_fromform,
							success: function(response){
								window.location.href = "themes.php?page=base.php&reset=true";
							},
							error: function(err){
								jQuery.facebox("Error!");
							}
						});	
					});
				});	
				jQuery('#save_button').click(function(e){
					var options_fromform = jQuery('#buildform').serialize();
					var save_button = jQuery(this);
					
					e.preventDefault();
					jQuery.facebox(function(){
						jQuery.ajax({
							type: "POST",
							url: "themes.php?page=base.php",
							data: options_fromform,
							success: function(response){
								jQuery.facebox('Settings Saved!');
								setTimeout(function(){
									jQuery(document).trigger('close.facebox');
								},1500);
							},
							error: function(err){
								jQuery.facebox("Error!");
							}
						});
					});	
					return false;
				});
			});
		</script>
		<?php
	}  //end of theme accesibility mode
}
	
add_action('admin_menu', 'startit');
add_action('admin_head', 'build_admin_head');

// Hostenko 
// убираем виджеты с дашборда
function remove_dashboard_widgets(){
  global$wp_meta_boxes;
  unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_plugins']);
  unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_primary']);
  unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_secondary']); 
}
add_action('wp_dashboard_setup', 'remove_dashboard_widgets');

// Виджет темы в dashboard
add_action('wp_dashboard_setup', 'my_custom_dashboard_widgets');
function my_custom_dashboard_widgets() {
global $wp_meta_boxes;
wp_add_dashboard_widget('custom_help_widget', 'Описание темы', 'custom_dashboard_help');
}
function custom_dashboard_help() {
echo '<a href="http://hostenko.com"><img src="http://hostenko.com/pics/widget_logo.png" style="float: left; margin: 0 10px 10px 0;"></a>
<p><b>Перед наполнением Вашего сайта информацией рекомендуем ознакомиться с <a href="http://hostenko.com/theme_description.php?theme=31">руководством по данной теме</a></b>.</p>
<p>Тема переведена <a href="http://hostenko.com">Hostenko</a> — специализированным хостингом для сайтов на WordPress с мастером его автоматической установки.</p>';
}

// Копирайт в футере
function remove_footer_admin () {
    echo 'Русские <a href="http://hostenko.com/themes">WordPress темы</a> — <a href="http://hostenko.com">Hostenko</a>';
} 
add_filter('admin_footer_text', 'remove_footer_admin');

// Меню Hостенко
add_action("admin_bar_menu", "customize_menu");
function customize_menu(){
global $wp_admin_bar;
  $wp_admin_bar->add_menu(array(
   "id" => "hostenko_menu",
   "title" => "Hostenko",
   "href" => "http://hostenko.com",
   "meta" => array("target" => "blank")
));
$wp_admin_bar->add_menu(array(
   "id" => "hostenko_menu_child",
    "title" => "Личный кабинет",
    "parent" => "hostenko_menu",
    "href" => "http://hostenko.com/cabinet",
	"meta" => array("target" => "blank")
));
$wp_admin_bar->add_menu(array(
   "id" => "hostenko_menu_child2",
    "title" => "WordPress темы",
    "parent" => "hostenko_menu",
    "href" => "http://hostenko.com/themes",
	"meta" => array("target" => "blank")
));
$wp_admin_bar->add_menu(array(
   "id" => "hostenko_menu_child3",
    "title" => "Блог Hostenko",
    "parent" => "hostenko_menu",
    "href" => "http://blog.hostenko.com",
	"meta" => array("target" => "blank")
));
}
// RSS-виджет Wordpresso
function wordpresso_rss_output(){
    echo '<div class="rss-widget">';
    echo '<a href="http://wordpresso.org"><img src="http://wordpresso.org/pics/widget_logo.png" style="float: left; margin: 0 10px 10px 0;"></a><br style="clear:both;"/>'; 
       wp_widget_rss_output(array(
            'url' => 'http://feeds.feedburner.com/Wordpresso',
            'title' => 'Wordpresso RSS',
            'items' => 3, 
            'show_summary' => 1,
            'show_author' => 0,
            'show_date' => 1
       ));
       
       echo "</div>";
}
add_action('wp_dashboard_setup', 'wordpresso_rss_widget');
function wordpresso_rss_widget(){
wp_add_dashboard_widget( 'wordpresso-rss', 'Wordpresso RSS', 'wordpresso_rss_output');
}

?>